package app

import (
	"cake_crm/internal/models/storage"
	proto "cake_crm/proto"
	"context"
)

type Server struct {
	proto.UnimplementedCRMServer
	storage storage.IStorage
}

func NewServer(storage storage.IStorage) *Server {
	return &Server{
		storage: storage,
	}
}

func (s *Server) GetCatalog(ctx context.Context, _ *proto.GetCatalogReq) (*proto.CatalogRsp, error) {
	categories, err := s.storage.GetCatalog(ctx)
	if err != nil {
		return nil, err
	}
	return &proto.CatalogRsp{Categories: categories}, nil
}

func (s *Server) GetPositions(ctx context.Context, req *proto.GetPositionsReq) (*proto.PositionsRsp, error) {
	products, err := s.storage.GetPositions(ctx, req.Id)
	if err != nil {
		return nil, err
	}
	return &proto.PositionsRsp{Products: products}, nil
}

func (s *Server) GetProduct(ctx context.Context, req *proto.GetProductReq) (*proto.ProductRsp, error) {
	product, err := s.storage.GetProduct(ctx, req.Id)
	if err != nil {
		return nil, err
	}
	return &proto.ProductRsp{Product: product}, nil
}

func (s *Server) GetBreadcrumbs(ctx context.Context, req *proto.GetBreadcrumbsReq) (*proto.BreadcrumbsRsp, error) {
	breadcrumbs, err := s.storage.GetBreadcrumbs(ctx, req.Id)
	if err != nil {
		return nil, err
	}
	return &proto.BreadcrumbsRsp{Categories: breadcrumbs}, nil
}
